@@ -1,41 +1,29 @@
 /*
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "autocorrectionwidget.h"
 #include "widgets/configureimmutablewidgetutils.h"
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include "autocorrection.h"
-#include "ui_autocorrectionwidget.h"
-#include "import/importlibreofficeautocorrection.h"
-#include "import/importkmailautocorrection.h"
 #include "import/importabstractautocorrection.h"
+#include "import/importkmailautocorrection.h"
+#include "import/importlibreofficeautocorrection.h"
+#include "ui_autocorrectionwidget.h"
 
 #include "settings/pimcommonsettings.h"
 #include <KPIMTextEdit/SelectSpecialCharDialog>
 #include <Libkdepim/LineEditCatchReturnKey>
 
-#include <KMessageBox>
 #include <KLocalizedString>
+#include <KMessageBox>
 
-#include <QTreeWidgetItem>
-#include <QMenu>
 #include <QFileDialog>
+#include <QMenu>
 #include <QPointer>
+#include <QTreeWidgetItem>
 
 using namespace PimCommon;
 
@@ -58,7 +46,7 @@ public:
     QSet<QString> m_upperCaseExceptions;
     QSet<QString> m_twoUpperLetterExceptions;
     QHash<QString, QString> m_autocorrectEntries;
-    Ui::AutoCorrectionWidget *ui = nullptr;
+    Ui::AutoCorrectionWidget *const ui;
     AutoCorrection *mAutoCorrection = nullptr;
     bool mWasChanged = false;
 };
@@ -124,10 +112,10 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     slotEnableDisableAbreviationList();
     slotEnableDisableTwoUpperEntry();
 
-    QMenu *menu = new QMenu(this);
+    auto menu = new QMenu(this);
     d->ui->importAutoCorrection->setMenu(menu);
 
-    QAction *act = new QAction(i18n("LibreOffice Autocorrection"), this);
+    auto act = new QAction(i18n("LibreOffice Autocorrection"), this);
     act->setData(QVariant::fromValue(AutoCorrectionWidget::LibreOffice));
     menu->addAction(act);
 
@@ -178,11 +166,11 @@ void AutoCorrectionWidget::loadAutoCorrectionAndException()
 {
     /* tab 2 - Custom Quotes */
     d->m_singleQuotes = d->mAutoCorrection->typographicSingleQuotes();
-    d->ui->singleQuote1->setText(d->m_singleQuotes.begin);
-    d->ui->singleQuote2->setText(d->m_singleQuotes.end);
+    d->ui->simpleQuoteBeginReplace->setText(d->m_singleQuotes.begin);
+    d->ui->simpleQuoteEndReplace->setText(d->m_singleQuotes.end);
     d->m_doubleQuotes = d->mAutoCorrection->typographicDoubleQuotes();
-    d->ui->doubleQuote1->setText(d->m_doubleQuotes.begin);
-    d->ui->doubleQuote2->setText(d->m_doubleQuotes.end);
+    d->ui->doubleQuoteBeginReplace->setText(d->m_doubleQuotes.begin);
+    d->ui->doubleQuoteEndReplace->setText(d->m_doubleQuotes.end);
     enableSingleQuotes(d->ui->typographicSingleQuotes->isChecked());
     enableDoubleQuotes(d->ui->typographicDoubleQuotes->isChecked());
 
@@ -289,7 +277,7 @@ void AutoCorrectionWidget::selectSingleQuoteCharOpen()
     dlg->autoInsertChar();
     if (dlg->exec()) {
         d->m_singleQuotes.begin = dlg->currentChar();
-        d->ui->singleQuote1->setText(d->m_singleQuotes.begin);
+        d->ui->simpleQuoteBeginReplace->setText(d->m_singleQuotes.begin);
         emitChanged();
     }
     delete dlg;
@@ -303,7 +291,7 @@ void AutoCorrectionWidget::selectSingleQuoteCharClose()
     dlg->autoInsertChar();
     if (dlg->exec()) {
         d->m_singleQuotes.end = dlg->currentChar();
-        d->ui->singleQuote2->setText(d->m_singleQuotes.end);
+        d->ui->simpleQuoteEndReplace->setText(d->m_singleQuotes.end);
         emitChanged();
     }
     delete dlg;
@@ -312,8 +300,8 @@ void AutoCorrectionWidget::selectSingleQuoteCharClose()
 void AutoCorrectionWidget::setDefaultSingleQuotes()
 {
     d->m_singleQuotes = d->mAutoCorrection->typographicDefaultSingleQuotes();
-    d->ui->singleQuote1->setText(d->m_singleQuotes.begin);
-    d->ui->singleQuote2->setText(d->m_singleQuotes.end);
+    d->ui->simpleQuoteBeginReplace->setText(d->m_singleQuotes.begin);
+    d->ui->simpleQuoteEndReplace->setText(d->m_singleQuotes.end);
     emitChanged();
 }
 
@@ -325,7 +313,7 @@ void AutoCorrectionWidget::selectDoubleQuoteCharOpen()
     dlg->autoInsertChar();
     if (dlg->exec()) {
         d->m_doubleQuotes.begin = dlg->currentChar();
-        d->ui->doubleQuote1->setText(d->m_doubleQuotes.begin);
+        d->ui->doubleQuoteBeginReplace->setText(d->m_doubleQuotes.begin);
         emitChanged();
     }
     delete dlg;
@@ -339,7 +327,7 @@ void AutoCorrectionWidget::selectDoubleQuoteCharClose()
     dlg->autoInsertChar();
     if (dlg->exec()) {
         d->m_doubleQuotes.end = dlg->currentChar();
-        d->ui->doubleQuote2->setText(d->m_doubleQuotes.end);
+        d->ui->doubleQuoteEndReplace->setText(d->m_doubleQuotes.end);
         emitChanged();
     }
     delete dlg;
@@ -348,8 +336,8 @@ void AutoCorrectionWidget::selectDoubleQuoteCharClose()
 void AutoCorrectionWidget::setDefaultDoubleQuotes()
 {
     d->m_doubleQuotes = d->mAutoCorrection->typographicDefaultDoubleQuotes();
-    d->ui->doubleQuote1->setText(d->m_doubleQuotes.begin);
-    d->ui->doubleQuote2->setText(d->m_doubleQuotes.end);
+    d->ui->doubleQuoteBeginReplace->setText(d->m_doubleQuotes.begin);
+    d->ui->doubleQuoteEndReplace->setText(d->m_doubleQuotes.end);
     emitChanged();
 }
 
@@ -413,7 +401,7 @@ void AutoCorrectionWidget::removeAutocorrectEntry()
 
         QString findStr;
         if (below) {
-            //qCDebug(PIMCOMMON_LOG) << "below";
+            // qCDebug(PIMCOMMON_LOG) << "below";
             findStr = item->text(0);
             delete item;
             item = nullptr;
@@ -469,7 +457,7 @@ void AutoCorrectionWidget::enableAddRemoveButton()
 
 void AutoCorrectionWidget::setFindReplaceText(QTreeWidgetItem *item, int column)
 {
-    Q_UNUSED(column);
+    Q_UNUSED(column)
     d->ui->find->setText(item->text(0));
     d->ui->replace->setText(item->text(1));
 }
@@ -559,7 +547,7 @@ void AutoCorrectionWidget::slotEnableDisableTwoUpperEntry()
 void AutoCorrectionWidget::slotImportAutoCorrection(QAction *act)
 {
     if (act) {
-        AutoCorrectionWidget::ImportFileType type = act->data().value<AutoCorrectionWidget::ImportFileType>();
+        auto type = act->data().value<AutoCorrectionWidget::ImportFileType>();
         QString title;
         QString filter;
         switch (type) {
