@@ -1,33 +1,21 @@
 /*
-  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "logactivitiesdialog.h"
-#include "logactivitieswidget.h"
 #include "logactivitiesmanager.h"
 #include "logactivitiespurposemenuwidget.h"
-#include <PimCommon/PimUtil>
-#include <KLocalizedString>
+#include "logactivitieswidget.h"
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
-#include <QVBoxLayout>
+#include <PimCommon/PimUtil>
+#include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QPushButton>
-#include <QCheckBox>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 
@@ -35,7 +23,7 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Log activities"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
 
     mLogWidget = new LogActivitiesWidget(this);
@@ -47,7 +35,7 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
     mainLayout->addWidget(mEnableLogActivities);
     connect(mEnableLogActivities, &QCheckBox::toggled, this, &LogActivitiesDialog::slotEnableLogActivities);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close | QDialogButtonBox::Save, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close | QDialogButtonBox::Save, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
 
     mClearButton = new QPushButton(i18n("Clear"), this);
@@ -58,7 +46,7 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
     mSaveButton->setObjectName(QStringLiteral("savebutton"));
     mSaveButton->setEnabled(false);
 
-    LogactivitiesPurposeMenuWidget *purposeMenu = new LogactivitiesPurposeMenuWidget(this, this);
+    auto purposeMenu = new LogactivitiesPurposeMenuWidget(this, this);
     mShareButton = new QPushButton(i18n("Share..."), this);
     mShareButton->setMenu(purposeMenu->menu());
     mShareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
@@ -93,8 +81,7 @@ void LogActivitiesDialog::slotActivityTextChanged(bool changed)
 void LogActivitiesDialog::slotSave()
 {
     const QString filter = i18n("All Files (*)");
-    PimCommon::Util::saveTextAs(PimCommon::LogActivitiesManager::self()->log(), filter, this, QUrl(),
-                                i18nc("@title:window", "Save Log"));
+    PimCommon::Util::saveTextAs(PimCommon::LogActivitiesManager::self()->log(), filter, this, QUrl(), i18nc("@title:window", "Save Log"));
 }
 
 void LogActivitiesDialog::slotEnableLogActivities(bool state)
@@ -125,7 +112,7 @@ void LogActivitiesDialog::slotClear()
 
 void LogActivitiesDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "LogActivitiesDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "LogActivitiesDialog");
     const QSize sizeDialog = group.readEntry("Size", QSize(800, 600));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
@@ -134,6 +121,6 @@ void LogActivitiesDialog::readConfig()
 
 void LogActivitiesDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "LogActivitiesDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "LogActivitiesDialog");
     group.writeEntry("Size", size());
 }
