@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,10 +8,10 @@
 #include "blacklistbalooemaillist.h"
 #include "pimcommonakonadi_debug.h"
 
-#include <QPainter>
-#include <QEvent>
-#include <KLocalizedString>
 #include <KEmailAddress>
+#include <KLocalizedString>
+#include <QEvent>
+#include <QPainter>
 using namespace PimCommon;
 
 BlackListBalooEmailList::BlackListBalooEmailList(QWidget *parent)
@@ -43,7 +43,7 @@ QHash<QString, bool> BlackListBalooEmailList::blackListItemChanged() const
     QHash<QString, bool> result;
     for (int i = 0; i < count(); ++i) {
         QListWidgetItem *element = item(i);
-        auto *blackListItem = static_cast<PimCommon::BlackListBalooEmailListItem *>(element);
+        auto blackListItem = static_cast<PimCommon::BlackListBalooEmailListItem *>(element);
         bool currentStatus = (blackListItem->checkState() == Qt::Checked);
         if (blackListItem->initializeStatus() != currentStatus) {
             result.insert(blackListItem->text(), currentStatus);
@@ -71,7 +71,7 @@ int BlackListBalooEmailList::setEmailFound(const QStringList &list)
 
         const QString mailToLower = mail.toLower();
         const QString emailToLower = email.toLower();
-        for (const QString &domain : qAsConst(mExcludeDomain)) {
+        for (const QString &domain : std::as_const(mExcludeDomain)) {
             if (email.endsWith(domain)) {
                 excludeDomain = true;
                 break;
@@ -81,7 +81,7 @@ int BlackListBalooEmailList::setEmailFound(const QStringList &list)
             continue;
         }
         if (!emailsAdded.contains(mail) && !emailsLower.contains(mailToLower) && !onlyEmails.contains(emailToLower)) {
-            auto *item = new BlackListBalooEmailListItem(this);
+            auto item = new BlackListBalooEmailListItem(this);
             if (mEmailBlackList.contains(mail)) {
                 item->setCheckState(Qt::Checked);
                 item->setInitializeStatus(true);
