@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "createresource.h"
@@ -21,12 +9,12 @@
 #include "pimcommonakonadi_debug.h"
 #include <KLocalizedString>
 
-#include <agenttype.h>
-#include <agentmanager.h>
 #include <agentinstancecreatejob.h>
+#include <agentmanager.h>
+#include <agenttype.h>
 
-#include <QDBusReply>
 #include <QDBusInterface>
+#include <QDBusReply>
 #include <QMetaMethod>
 
 using namespace Akonadi;
@@ -42,7 +30,7 @@ CreateResource::~CreateResource()
 {
 }
 
-//code from accountwizard
+// code from accountwizard
 static QVariant::Type argumentType(const QMetaObject *mo, const QString &method)
 {
     QMetaMethod m;
@@ -94,7 +82,7 @@ QString CreateResource::createResource(const QString &resources, const QString &
     }
 
     Q_EMIT createResourceInfo(i18n("Creating resource instance for '%1'...", type.name()));
-    AgentInstanceCreateJob *job = new AgentInstanceCreateJob(type, this);
+    auto job = new AgentInstanceCreateJob(type, this);
     if (job->exec()) {
         Akonadi::AgentInstance instance = job->instance();
 
@@ -117,7 +105,8 @@ QString CreateResource::createResource(const QString &resources, const QString &
                 QVariant arg = it.value();
                 const QVariant::Type targetType = argumentType(iface.metaObject(), methodName);
                 if (!arg.canConvert(targetType)) {
-                    Q_EMIT createResourceError(i18n("Could not convert value of setting '%1' to required type %2.", it.key(), QString::fromLatin1(QVariant::typeToName(targetType))));
+                    Q_EMIT createResourceError(
+                        i18n("Could not convert value of setting '%1' to required type %2.", it.key(), QString::fromLatin1(QVariant::typeToName(targetType))));
                     return QString();
                 }
                 arg.convert(targetType);
@@ -127,6 +116,11 @@ QString CreateResource::createResource(const QString &resources, const QString &
                     return QString();
                 }
             }
+            QDBusReply<void> reply = iface.call(QStringLiteral("save"));
+            if (!reply.isValid()) {
+                Q_EMIT createResourceError(i18n("Could not save settings: %1", reply.error().message()));
+                return QString();
+            }
             instance.reconfigure();
             if (synchronizeTree) {
                 instance.synchronizeCollectionTree();
